### PyAutoReadme:

This is a Readme Generator for Python Projects. This can be used to generate Readme(s) faster, without putting a lot of efforts to assist the community developers in a much better and easier way!


### How to Use?

	from pyautoreaadme import readme

	readme.create() # call to create a readme
	readme.update() # call to update the readme after changing data in readme.json


### Authors:

Nishant Sharma

### License:

mit

### Scripts:

**create readme:**

	readme.create() // callable function


**update readme:**

	readme.update() // callable function


### Reader's Notes:

**Main File to Use:**  readme.py

**Guess What?:**  This Readme is made using this library only!

**Feel free to Reach me out for collabs!:**  I am a curious developer, who wants to build 2 Impact, Eager to Connect to other Curious Developers!


### Check These Out:

[My Instagram](https://www.instagram.com/_nishan.t/) | [My LinkedIn](https://www.linkedin.com/in/nishantsh20/) 

### Project Dependencies:

	os
	json
	colorama==0.4.4
